==> wecube-v3.2.6.zip: wecube-platform-v3.2.6/wecube-portal/src/const/menus.js <==
export const MENUS = [
  {
    code: 'JOBS',
    cnName: '任务',
    enName: 'Tasks'
  },
  {
    code: 'DESIGNING',
    cnName: '设计',
    enName: 'Design'
  },
  {
    code: 'IMPLEMENTATION',
    cnName: '执行',
    enName: 'Execute'
  },
  {
    code: 'MONITORING',
    cnName: '监测',
    enName: 'Monitor'
  },
  {
    code: 'INTELLIGENCE_OPS',
    cnName: '智慧',
    enName: 'Intelligence'
  },
  {
    code: 'ADJUSTMENT',
    cnName: '调整',
    enName: 'Adjust'
  },
  {
    code: 'COLLABORATION',
    cnName: '协同',
    enName: 'Conjoin'
  },
  {
    code: 'ADMIN',
    cnName: '系统',
    enName: 'Admin'
  },

  {
    code: 'COLLABORATION_PLUGIN_MANAGEMENT',
    cnName: '插件注册',
    enName: 'Plugin Management',
    link: '/collaboration/plugin-management'
  },
  {
    code: 'COLLABORATION_WORKFLOW_ORCHESTRATION',
    cnName: '任务编排',
    enName: 'Workflow Management',
    link: '/collaboration/workflow-orchestration'
  },
  {
    code: 'ADMIN_SYSTEM_PARAMS',
    cnName: '系统参数',
    enName: 'System Params',
    link: '/admin/system-params'
  },
  {
    code: 'ADMIN_RESOURCES_MANAGEMENT',
    cnName: '资源管理',
    enName: 'Resources',
    link: '/admin/resources'
  },
  {
    code: 'ADMIN_CERTIFICATION',
    cnName: '授权管理',
    enName: 'Certification',
    link: '/admin/certification'
  },
  {
    code: 'IMPLEMENTATION_WORKFLOW_EXECUTION',
    cnName: '编排执行',
    enName: 'Workflow Execution',
    link: '/implementation/workflow-execution'
  },
  {
    code: 'IMPLEMENTATION_BATCH_EXECUTION',
    cnName: '批量执行',
    enName: 'Batch Execution',
    link: '/implementation/batch-execution'
  },
  {
    code: 'ADMIN_USER_ROLE_MANAGEMENT',
    cnName: '权限管理',
    enName: 'Permissions',
    link: '/admin/user-role-management'
  },
  {
    code: 'ADMIN_SYSTEM_DATA_MODEL',
    cnName: '系统数据模型',
    enName: 'Data Model',
    link: '/admin/system-data-model'
  },
  {
    code: 'ADMIN_SYSTEM_WORKFLOW_REPORT',
    cnName: '编排执行报表',
    enName: 'Workflow Report',
    link: '/admin/workflow-report'
  }
]

==> wecube-v4.2.1.zip: wecube-platform-v4.2.1/wecube-portal/src/const/menus.js <==
export const MENUS = [
  {
    code: 'JOBS',
    cnName: '任务',
    enName: 'Tasks'
  },
  {
    code: 'DESIGNING',
    cnName: '设计',
    enName: 'Design'
  },
  {
    code: 'IMPLEMENTATION',
    cnName: '执行',
    enName: 'Execute'
  },
  {
    code: 'MONITORING',
    cnName: '监测',
    enName: 'Monitor'
  },
  {
    code: 'INTELLIGENCE_OPS',
    cnName: '智慧',
    enName: 'Intelligence'
  },
  {
    code: 'ADJUSTMENT',
    cnName: '调整',
    enName: 'Adjust'
  },
  {
    code: 'COLLABORATION',
    cnName: '协同',
    enName: 'Conjoin'
  },
  {
    code: 'ADMIN',
    cnName: '系统',
    enName: 'Admin'
  },

  {
    code: 'COLLABORATION_PLUGIN_MANAGEMENT',
    cnName: '插件注册',
    enName: 'Plugin Management',
    link: '/collaboration/plugin-management'
  },
  {
    code: 'COLLABORATION_WORKFLOW_ORCHESTRATION',
    cnName: '编排设计',
    enName: 'Workflow Management',
    link: '/collaboration/workflow'
  },
  {
    code: 'ADMIN_SYSTEM_PARAMS',
    cnName: '系统参数',
    enName: 'System Params',
    link: '/admin/system-params'
  },
  {
    code: 'ADMIN_RESOURCES_MANAGEMENT',
    cnName: '资源管理',
    enName: 'Resources Config',
    link: '/admin/resources'
  },
  {
    code: 'ADMIN_CERTIFICATION',
    cnName: '授权管理',
    enName: 'Certification Config',
    link: '/admin/certification'
  },
  {
    code: 'IMPLEMENTATION_WORKFLOW_EXECUTION',
    cnName: '编排执行',
    enName: 'Workflow Execution',
    link: '/implementation/workflow-execution'
  },
  {
    code: 'IMPLEMENTATION_BATCH_EXECUTION',
    cnName: '批量执行',
    enName: 'Batch Execution',
    link: '/implementation/batch-execution'
  },
  {
    code: 'ADMIN_USER_ROLE_MANAGEMENT',
    cnName: '权限管理',
    enName: 'Auth Config',
    link: '/admin/user-role-management'
  },
  {
    code: 'ADMIN_SYSTEM_DATA_MODEL',
    cnName: '系统模型',
    enName: 'System Data Model',
    link: '/admin/system-data-model'
  },
  {
    code: 'ADMIN_SYSTEM_WORKFLOW_REPORT',
    cnName: '编排报表',
    enName: 'Workflow Report',
    link: '/admin/workflow-report'
  }
]
